stravalib.client.BatchedResultsIterator
=======================================

.. currentmodule:: stravalib.client

.. autoclass:: BatchedResultsIterator


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~BatchedResultsIterator.__init__
      ~BatchedResultsIterator.next
      ~BatchedResultsIterator.reset





   .. rubric:: Attributes

   .. autosummary::

      ~BatchedResultsIterator.default_per_page
